import i18next from "i18next";

const scaleQuestions = [
    "sus-question-easy-to-use", // I thought CageCalc is easy to use
    "sus-question-like-to-use-frequently", // I would like to use CageCalc frequently
    "sus-question-unnecessarily-complex", // I find CageCalc unnecessarily complex
    "sus-question-need-support-of-technical-person", // I think that I need the support of a technical person to be able to use CageCalc
    "sus-question-well-integrated", // I found various functions in CageCalc were well integrated
    "sus-question-inconsistency", // I thought there was too much inconsistency in CageCalc
    "sus-question-learn-quickly", // I would imagine that most people would learn to use CageCalc very quickly
    "sus-question-cumbersome", // I found CageCalc very cumbersome to use
    "sus-question-confident", // I felt very confident using CageCalc
    "sus-question-need-to-learn" // I needed to learn a lot of things before I could get going with CageCalc
];

const freetextQuestions = [
    "question-whats-missing", // Welche Funktion fehlt dir?
    "question-pain-points", // Was muss aus deiner Sicht an XX geändert werden?
    "question-other-feedback" // Was willst du uns mitgeben?
]

function prepareQuestionnaire() {
    const form = document.getElementById("sus-form");

    scaleQuestions.forEach((key, index) => {
        const field = document.createElement("div");
        field.className = "field";
        field.id = key;
        field.innerHTML = `
          <label class="label" data-i18n="${key}"></label>
          <p class="control">
            <input class="sus-slider" type="range" min="1" max="5" step="1" name=${key} required>
            <div class="slider-labels">
              <span data-i18n="strongly-disagree">${i18next.t('strongly-disagree')}</span>
              <span data-i18n="strongly-agree">${i18next.t('strongly-agree')}</span>
            </div>
          </p>
        `;
        form.insertBefore(field, form.querySelector('#sus-control'));
    });

    freetextQuestions.forEach((key, index) => {
        const field = document.createElement("div");
        field.classList.add("field");
        field.id = key;
        field.innerHTML = `
            <label class="label" data-i18n="${key}"></label>
            <p class="control">
                <input class="input" type="text" name=${key}/>
            </p>
                `
        form.insertBefore(field, form.querySelector('#sus-control'));
    })
    return form;
}

window.addEventListener('DOMContentLoaded', () => {
    let form = prepareQuestionnaire();
    form.addEventListener("submit", async (e) => {
        e.preventDefault();

        const formData = new FormData(form);
        const jsonData = {};

        for (let [key, value] of formData.entries()) {
            if (key.startsWith("sws-question")) {
                jsonData[key] = parseInt(value, 10);
            } else {
                jsonData[key] = value;
            }

        }

        try {
            const response = await fetch("https://storandom.hyteck.de/submit", {
                method: "POST",
                headers: {
                    "Content-Type": "application/json"
                },
                body: JSON.stringify(jsonData)
            });

            const messageDiv = document.getElementById("response-message");

            if (response.ok) {
                messageDiv.className = "notification is-success";
                messageDiv.setAttribute("data-i18n", "submit-success");
                messageDiv.textContent = i18next.t("Survey submitted successfully!");
            } else {
                messageDiv.className = "notification is-danger";
                messageDiv.setAttribute("data-i18n", "submit-error");
                messageDiv.textContent = i18next.t("There was an error submitting the survey.");
            }

            messageDiv.classList.remove("is-hidden");

        } catch (error) {
            const messageDiv = document.getElementById("response-message");
            messageDiv.className = "notification is-danger";
            messageDiv.removeAttribute("data-i18n"); // For dynamic error message
            messageDiv.textContent = i18next.t("Network error: {{errorMessage}}",{"errorMessage": error.message});
            messageDiv.classList.remove("is-hidden");
        }
    });
});
